To run this demo start the Bokeh server application:

    bokeh serve bokeh_server.py --allow-websocket-origin=127.0.0.1:5000

And then in a seprate window execute:

    python flask_server.py

Then navigate to http://127.0.0.1:5000
